# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_user_create_users_parameters_users_inner_customfields_inner import CoreUserCreateUsersParametersUsersInnerCustomfieldsInner
from poodle_async_full.models.core_user_create_users_parameters_users_inner_preferences_inner import CoreUserCreateUsersParametersUsersInnerPreferencesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreUserUpdateUsersParametersUsersInner(BaseModel):
    """
    CoreUserUpdateUsersParametersUsersInner
    """ # noqa: E501
    address: Optional[StrictStr] = Field(default=None, description="Postal address")
    alternatename: Optional[StrictStr] = Field(default=None, description="The alternate name of the user")
    auth: Optional[StrictStr] = Field(default='', description="Auth plugins include manual, ldap, etc")
    calendartype: Optional[StrictStr] = Field(default='', description="Calendar type such as \"gregorian\", must exist on server")
    city: Optional[StrictStr] = Field(default=None, description="Home city of the user")
    country: Optional[StrictStr] = Field(default=None, description="Home country code of the user, such as AU or CZ")
    customfields: Optional[List[CoreUserCreateUsersParametersUsersInnerCustomfieldsInner]] = Field(default=None, description="User custom fields (also known as user profil fields)")
    department: Optional[StrictStr] = Field(default=None, description="Department")
    description: Optional[StrictStr] = Field(default=None, description="User profile description, no HTML")
    email: Optional[StrictStr] = Field(default='', description="A valid and unique email address")
    firstname: Optional[StrictStr] = Field(default='', description="The first name(s) of the user")
    firstnamephonetic: Optional[StrictStr] = Field(default=None, description="The first name(s) phonetically of the user")
    id: Optional[StrictInt] = Field(description="ID of the user")
    idnumber: Optional[StrictStr] = Field(default=None, description="An arbitrary ID code number perhaps from the institution")
    institution: Optional[StrictStr] = Field(default=None, description="Institution")
    interests: Optional[StrictStr] = Field(default=None, description="User interests (separated by commas)")
    lang: Optional[StrictStr] = Field(default='', description="Language code such as \"en\", must exist on server")
    lastname: Optional[StrictStr] = Field(default=None, description="The family name of the user")
    lastnamephonetic: Optional[StrictStr] = Field(default=None, description="The family name phonetically of the user")
    maildisplay: Optional[StrictInt] = Field(default=None, description="Email visibility")
    mailformat: Optional[StrictInt] = Field(default=None, description="Mail format code is 0 for plain text, 1 for HTML etc")
    middlename: Optional[StrictStr] = Field(default=None, description="The middle name of the user")
    password: Optional[StrictStr] = Field(default='', description="Plain text password consisting of any characters")
    phone1: Optional[StrictStr] = Field(default=None, description="Phone")
    phone2: Optional[StrictStr] = Field(default=None, description="Mobile phone")
    preferences: Optional[List[CoreUserCreateUsersParametersUsersInnerPreferencesInner]] = Field(default=None, description="User preferences")
    suspended: Optional[StrictBool] = Field(default=None, description="Suspend user account, either false to enable user login or true to disable it")
    theme: Optional[StrictStr] = Field(default=None, description="Theme name such as \"standard\", must exist on server")
    timezone: Optional[StrictStr] = Field(default=None, description="Timezone code such as Australia/Perth, or 99 for default")
    username: Optional[StrictStr] = Field(default='', description="Username policy is defined in Moodle security config.")
    userpicture: Optional[StrictInt] = Field(default=None, description="The itemid where the new user picture has been uploaded to, 0 to delete")
    __properties: ClassVar[List[str]] = ["address", "alternatename", "auth", "calendartype", "city", "country", "customfields", "department", "description", "email", "firstname", "firstnamephonetic", "id", "idnumber", "institution", "interests", "lang", "lastname", "lastnamephonetic", "maildisplay", "mailformat", "middlename", "password", "phone1", "phone2", "preferences", "suspended", "theme", "timezone", "username", "userpicture"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreUserUpdateUsersParametersUsersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in customfields (list)
        _items = []
        if self.customfields:
            for _item_customfields in self.customfields:
                if _item_customfields:
                    _items.append(_item_customfields.to_dict())
            _dict['customfields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in preferences (list)
        _items = []
        if self.preferences:
            for _item_preferences in self.preferences:
                if _item_preferences:
                    _items.append(_item_preferences.to_dict())
            _dict['preferences'] = _items
        # set to None if address (nullable) is None
        # and model_fields_set contains the field
        if self.address is None and "address" in self.model_fields_set:
            _dict['address'] = None

        # set to None if alternatename (nullable) is None
        # and model_fields_set contains the field
        if self.alternatename is None and "alternatename" in self.model_fields_set:
            _dict['alternatename'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if department (nullable) is None
        # and model_fields_set contains the field
        if self.department is None and "department" in self.model_fields_set:
            _dict['department'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if firstnamephonetic (nullable) is None
        # and model_fields_set contains the field
        if self.firstnamephonetic is None and "firstnamephonetic" in self.model_fields_set:
            _dict['firstnamephonetic'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if institution (nullable) is None
        # and model_fields_set contains the field
        if self.institution is None and "institution" in self.model_fields_set:
            _dict['institution'] = None

        # set to None if interests (nullable) is None
        # and model_fields_set contains the field
        if self.interests is None and "interests" in self.model_fields_set:
            _dict['interests'] = None

        # set to None if lastname (nullable) is None
        # and model_fields_set contains the field
        if self.lastname is None and "lastname" in self.model_fields_set:
            _dict['lastname'] = None

        # set to None if lastnamephonetic (nullable) is None
        # and model_fields_set contains the field
        if self.lastnamephonetic is None and "lastnamephonetic" in self.model_fields_set:
            _dict['lastnamephonetic'] = None

        # set to None if maildisplay (nullable) is None
        # and model_fields_set contains the field
        if self.maildisplay is None and "maildisplay" in self.model_fields_set:
            _dict['maildisplay'] = None

        # set to None if mailformat (nullable) is None
        # and model_fields_set contains the field
        if self.mailformat is None and "mailformat" in self.model_fields_set:
            _dict['mailformat'] = None

        # set to None if middlename (nullable) is None
        # and model_fields_set contains the field
        if self.middlename is None and "middlename" in self.model_fields_set:
            _dict['middlename'] = None

        # set to None if phone1 (nullable) is None
        # and model_fields_set contains the field
        if self.phone1 is None and "phone1" in self.model_fields_set:
            _dict['phone1'] = None

        # set to None if phone2 (nullable) is None
        # and model_fields_set contains the field
        if self.phone2 is None and "phone2" in self.model_fields_set:
            _dict['phone2'] = None

        # set to None if suspended (nullable) is None
        # and model_fields_set contains the field
        if self.suspended is None and "suspended" in self.model_fields_set:
            _dict['suspended'] = None

        # set to None if theme (nullable) is None
        # and model_fields_set contains the field
        if self.theme is None and "theme" in self.model_fields_set:
            _dict['theme'] = None

        # set to None if timezone (nullable) is None
        # and model_fields_set contains the field
        if self.timezone is None and "timezone" in self.model_fields_set:
            _dict['timezone'] = None

        # set to None if userpicture (nullable) is None
        # and model_fields_set contains the field
        if self.userpicture is None and "userpicture" in self.model_fields_set:
            _dict['userpicture'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreUserUpdateUsersParametersUsersInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreUserUpdateUsersParametersUsersInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "address": obj.get("address"),
            "alternatename": obj.get("alternatename"),
            "auth": obj.get("auth") if obj.get("auth") is not None else '',
            "calendartype": obj.get("calendartype") if obj.get("calendartype") is not None else '',
            "city": obj.get("city"),
            "country": obj.get("country"),
            "customfields": [CoreUserCreateUsersParametersUsersInnerCustomfieldsInner.from_dict(_item) for _item in obj["customfields"]] if obj.get("customfields") is not None else None,
            "department": obj.get("department"),
            "description": obj.get("description"),
            "email": obj.get("email") if obj.get("email") is not None else '',
            "firstname": obj.get("firstname") if obj.get("firstname") is not None else '',
            "firstnamephonetic": obj.get("firstnamephonetic"),
            "id": obj.get("id"),
            "idnumber": obj.get("idnumber"),
            "institution": obj.get("institution"),
            "interests": obj.get("interests"),
            "lang": obj.get("lang") if obj.get("lang") is not None else '',
            "lastname": obj.get("lastname"),
            "lastnamephonetic": obj.get("lastnamephonetic"),
            "maildisplay": obj.get("maildisplay"),
            "mailformat": obj.get("mailformat"),
            "middlename": obj.get("middlename"),
            "password": obj.get("password") if obj.get("password") is not None else '',
            "phone1": obj.get("phone1"),
            "phone2": obj.get("phone2"),
            "preferences": [CoreUserCreateUsersParametersUsersInnerPreferencesInner.from_dict(_item) for _item in obj["preferences"]] if obj.get("preferences") is not None else None,
            "suspended": obj.get("suspended"),
            "theme": obj.get("theme"),
            "timezone": obj.get("timezone"),
            "username": obj.get("username") if obj.get("username") is not None else '',
            "userpicture": obj.get("userpicture")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_customfields_inner import CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner
from poodle_async_full.models.core_course_create_courses_parameters_courses_inner_courseformatoptions_inner import CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCourseCreateCoursesParametersCoursesInner(BaseModel):
    """
    CoreCourseCreateCoursesParametersCoursesInner
    """ # noqa: E501
    categoryid: Optional[StrictInt] = Field(description="category id")
    completionnotify: Optional[StrictInt] = Field(default=None, description="1: yes 0: no")
    courseformatoptions: Optional[List[CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner]] = Field(default=None, description="additional options for particular course format")
    customfields: Optional[List[CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner]] = Field(default=None, description="custom fields for the course")
    defaultgroupingid: Optional[StrictInt] = Field(default=0, description="default grouping id")
    enablecompletion: Optional[StrictInt] = Field(default=None, description="Enabled, control via completion and activity settings. Disabled,                                         not shown in activity settings.")
    enddate: Optional[StrictInt] = Field(default=None, description="timestamp when the course end")
    forcetheme: Optional[StrictStr] = Field(default=None, description="name of the force theme")
    format: Optional[StrictStr] = Field(default='topics', description="course format: weeks, topics, social, site,..")
    fullname: Optional[StrictStr] = Field(description="full name")
    groupmode: Optional[StrictInt] = Field(default=0, description="no group, separate, visible")
    groupmodeforce: Optional[StrictInt] = Field(default=0, description="1: yes, 0: no")
    hiddensections: Optional[StrictInt] = Field(default=None, description="(deprecated, use courseformatoptions) How the hidden sections in the course are displayed to students")
    idnumber: Optional[StrictStr] = Field(default=None, description="id number")
    lang: Optional[StrictStr] = Field(default=None, description="forced course language")
    maxbytes: Optional[StrictInt] = Field(default=0, description="largest size of file that can be uploaded into the course")
    newsitems: Optional[StrictInt] = Field(default=5, description="number of recent items appearing on the course page")
    numsections: Optional[StrictInt] = Field(default=None, description="(deprecated, use courseformatoptions) number of weeks/topics")
    shortname: Optional[StrictStr] = Field(description="course short name")
    showgrades: Optional[StrictInt] = Field(default=1, description="1 if grades are shown, otherwise 0")
    showreports: Optional[StrictInt] = Field(default=0, description="are activity report shown (yes = 1, no =0)")
    startdate: Optional[StrictInt] = Field(default=None, description="timestamp when the course start")
    summary: Optional[StrictStr] = Field(default=None, description="summary")
    summaryformat: Optional[StrictInt] = Field(default=1, description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    visible: Optional[StrictInt] = Field(default=1, description="1: available to student, 0: not available")
    __properties: ClassVar[List[str]] = ["categoryid", "completionnotify", "courseformatoptions", "customfields", "defaultgroupingid", "enablecompletion", "enddate", "forcetheme", "format", "fullname", "groupmode", "groupmodeforce", "hiddensections", "idnumber", "lang", "maxbytes", "newsitems", "numsections", "shortname", "showgrades", "showreports", "startdate", "summary", "summaryformat", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseCreateCoursesParametersCoursesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in courseformatoptions (list)
        _items = []
        if self.courseformatoptions:
            for _item_courseformatoptions in self.courseformatoptions:
                if _item_courseformatoptions:
                    _items.append(_item_courseformatoptions.to_dict())
            _dict['courseformatoptions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in customfields (list)
        _items = []
        if self.customfields:
            for _item_customfields in self.customfields:
                if _item_customfields:
                    _items.append(_item_customfields.to_dict())
            _dict['customfields'] = _items
        # set to None if categoryid (nullable) is None
        # and model_fields_set contains the field
        if self.categoryid is None and "categoryid" in self.model_fields_set:
            _dict['categoryid'] = None

        # set to None if completionnotify (nullable) is None
        # and model_fields_set contains the field
        if self.completionnotify is None and "completionnotify" in self.model_fields_set:
            _dict['completionnotify'] = None

        # set to None if defaultgroupingid (nullable) is None
        # and model_fields_set contains the field
        if self.defaultgroupingid is None and "defaultgroupingid" in self.model_fields_set:
            _dict['defaultgroupingid'] = None

        # set to None if enablecompletion (nullable) is None
        # and model_fields_set contains the field
        if self.enablecompletion is None and "enablecompletion" in self.model_fields_set:
            _dict['enablecompletion'] = None

        # set to None if enddate (nullable) is None
        # and model_fields_set contains the field
        if self.enddate is None and "enddate" in self.model_fields_set:
            _dict['enddate'] = None

        # set to None if forcetheme (nullable) is None
        # and model_fields_set contains the field
        if self.forcetheme is None and "forcetheme" in self.model_fields_set:
            _dict['forcetheme'] = None

        # set to None if format (nullable) is None
        # and model_fields_set contains the field
        if self.format is None and "format" in self.model_fields_set:
            _dict['format'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if groupmodeforce (nullable) is None
        # and model_fields_set contains the field
        if self.groupmodeforce is None and "groupmodeforce" in self.model_fields_set:
            _dict['groupmodeforce'] = None

        # set to None if hiddensections (nullable) is None
        # and model_fields_set contains the field
        if self.hiddensections is None and "hiddensections" in self.model_fields_set:
            _dict['hiddensections'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if maxbytes (nullable) is None
        # and model_fields_set contains the field
        if self.maxbytes is None and "maxbytes" in self.model_fields_set:
            _dict['maxbytes'] = None

        # set to None if newsitems (nullable) is None
        # and model_fields_set contains the field
        if self.newsitems is None and "newsitems" in self.model_fields_set:
            _dict['newsitems'] = None

        # set to None if numsections (nullable) is None
        # and model_fields_set contains the field
        if self.numsections is None and "numsections" in self.model_fields_set:
            _dict['numsections'] = None

        # set to None if shortname (nullable) is None
        # and model_fields_set contains the field
        if self.shortname is None and "shortname" in self.model_fields_set:
            _dict['shortname'] = None

        # set to None if showgrades (nullable) is None
        # and model_fields_set contains the field
        if self.showgrades is None and "showgrades" in self.model_fields_set:
            _dict['showgrades'] = None

        # set to None if showreports (nullable) is None
        # and model_fields_set contains the field
        if self.showreports is None and "showreports" in self.model_fields_set:
            _dict['showreports'] = None

        # set to None if startdate (nullable) is None
        # and model_fields_set contains the field
        if self.startdate is None and "startdate" in self.model_fields_set:
            _dict['startdate'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseCreateCoursesParametersCoursesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseCreateCoursesParametersCoursesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "categoryid": obj.get("categoryid"),
            "completionnotify": obj.get("completionnotify"),
            "courseformatoptions": [CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner.from_dict(_item) for _item in obj["courseformatoptions"]] if obj.get("courseformatoptions") is not None else None,
            "customfields": [CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner.from_dict(_item) for _item in obj["customfields"]] if obj.get("customfields") is not None else None,
            "defaultgroupingid": obj.get("defaultgroupingid") if obj.get("defaultgroupingid") is not None else 0,
            "enablecompletion": obj.get("enablecompletion"),
            "enddate": obj.get("enddate"),
            "forcetheme": obj.get("forcetheme"),
            "format": obj.get("format") if obj.get("format") is not None else 'topics',
            "fullname": obj.get("fullname"),
            "groupmode": obj.get("groupmode") if obj.get("groupmode") is not None else 0,
            "groupmodeforce": obj.get("groupmodeforce") if obj.get("groupmodeforce") is not None else 0,
            "hiddensections": obj.get("hiddensections"),
            "idnumber": obj.get("idnumber"),
            "lang": obj.get("lang"),
            "maxbytes": obj.get("maxbytes") if obj.get("maxbytes") is not None else 0,
            "newsitems": obj.get("newsitems") if obj.get("newsitems") is not None else 5,
            "numsections": obj.get("numsections"),
            "shortname": obj.get("shortname"),
            "showgrades": obj.get("showgrades") if obj.get("showgrades") is not None else 1,
            "showreports": obj.get("showreports") if obj.get("showreports") is not None else 0,
            "startdate": obj.get("startdate"),
            "summary": obj.get("summary"),
            "summaryformat": obj.get("summaryformat") if obj.get("summaryformat") is not None else 1,
            "visible": obj.get("visible") if obj.get("visible") is not None else 1
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreTagGetTagindexResponse(BaseModel):
    """
    tag index
    """ # noqa: E501
    anchor: Optional[StrictStr] = Field(default=None, description="name of anchor")
    component: Optional[StrictStr] = Field(description="component")
    content: Optional[StrictStr] = Field(description="title")
    exclusivetext: Optional[StrictStr] = Field(default=None, description="text for exclusive link")
    exclusiveurl: Optional[StrictStr] = Field(default=None, description="URL for exclusive link")
    hascontent: Optional[StrictInt] = Field(description="whether the content is present")
    itemtype: Optional[StrictStr] = Field(description="itemtype")
    nextpageurl: Optional[StrictStr] = Field(default=None, description="URL for the next page")
    prevpageurl: Optional[StrictStr] = Field(default=None, description="URL for the next page")
    ta: Optional[StrictInt] = Field(description="tag area id")
    tagid: Optional[StrictInt] = Field(description="tag id")
    title: Optional[StrictStr] = Field(description="title")
    __properties: ClassVar[List[str]] = ["anchor", "component", "content", "exclusivetext", "exclusiveurl", "hascontent", "itemtype", "nextpageurl", "prevpageurl", "ta", "tagid", "title"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreTagGetTagindexResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if anchor (nullable) is None
        # and model_fields_set contains the field
        if self.anchor is None and "anchor" in self.model_fields_set:
            _dict['anchor'] = None

        # set to None if component (nullable) is None
        # and model_fields_set contains the field
        if self.component is None and "component" in self.model_fields_set:
            _dict['component'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if exclusivetext (nullable) is None
        # and model_fields_set contains the field
        if self.exclusivetext is None and "exclusivetext" in self.model_fields_set:
            _dict['exclusivetext'] = None

        # set to None if exclusiveurl (nullable) is None
        # and model_fields_set contains the field
        if self.exclusiveurl is None and "exclusiveurl" in self.model_fields_set:
            _dict['exclusiveurl'] = None

        # set to None if hascontent (nullable) is None
        # and model_fields_set contains the field
        if self.hascontent is None and "hascontent" in self.model_fields_set:
            _dict['hascontent'] = None

        # set to None if itemtype (nullable) is None
        # and model_fields_set contains the field
        if self.itemtype is None and "itemtype" in self.model_fields_set:
            _dict['itemtype'] = None

        # set to None if nextpageurl (nullable) is None
        # and model_fields_set contains the field
        if self.nextpageurl is None and "nextpageurl" in self.model_fields_set:
            _dict['nextpageurl'] = None

        # set to None if prevpageurl (nullable) is None
        # and model_fields_set contains the field
        if self.prevpageurl is None and "prevpageurl" in self.model_fields_set:
            _dict['prevpageurl'] = None

        # set to None if ta (nullable) is None
        # and model_fields_set contains the field
        if self.ta is None and "ta" in self.model_fields_set:
            _dict['ta'] = None

        # set to None if tagid (nullable) is None
        # and model_fields_set contains the field
        if self.tagid is None and "tagid" in self.model_fields_set:
            _dict['tagid'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreTagGetTagindexResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreTagGetTagindexResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "anchor": obj.get("anchor"),
            "component": obj.get("component"),
            "content": obj.get("content"),
            "exclusivetext": obj.get("exclusivetext"),
            "exclusiveurl": obj.get("exclusiveurl"),
            "hascontent": obj.get("hascontent"),
            "itemtype": obj.get("itemtype"),
            "nextpageurl": obj.get("nextpageurl"),
            "prevpageurl": obj.get("prevpageurl"),
            "ta": obj.get("ta"),
            "tagid": obj.get("tagid"),
            "title": obj.get("title")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModLessonGetLessonResponseLesson(BaseModel):
    """
    ModLessonGetLessonResponseLesson
    """ # noqa: E501
    activitylink: Optional[StrictInt] = Field(default=0, description="Id of the next activity to be linked once the lesson is completed")
    allowofflineattempts: StrictBool = Field(description="Whether to allow the lesson to be attempted offline in the mobile app")
    available: Optional[StrictInt] = Field(default=0, description="Available from")
    bgcolor: Optional[StrictStr] = Field(default='', description="Slideshow bgcolor")
    completionendreached: Optional[StrictInt] = Field(default=0, description="Require end reached for completion?")
    completiontimespent: Optional[StrictInt] = Field(default=0, description="Student must do this activity at least for")
    conditions: Optional[StrictStr] = Field(default='', description="Conditions to enable the lesson")
    course: StrictInt = Field(description="Foreign key reference to the course this lesson is part of.")
    coursemodule: StrictInt = Field(description="Course module id.")
    custom: Optional[StrictBool] = Field(default=False, description="Custom scoring?")
    deadline: Optional[StrictInt] = Field(default=0, description="Available until")
    dependency: Optional[StrictInt] = Field(default=0, description="Dependent on (another lesson id)")
    displayleft: Optional[StrictBool] = Field(default=False, description="Display left pages menu?")
    displayleftif: Optional[StrictInt] = Field(default=0, description="Minimum grade to display menu")
    feedback: Optional[StrictBool] = Field(default=False, description="Display default feedback")
    grade: Optional[StrictInt] = Field(default=0, description="The total that the grade is scaled to be out of")
    height: Optional[StrictInt] = Field(default=0, description="Slideshow height")
    id: StrictInt = Field(description="Standard Moodle primary key.")
    intro: Optional[StrictStr] = Field(default='', description="Lesson introduction text.")
    introfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="introfiles")
    introformat: Optional[StrictInt] = Field(default=0, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(description="Forced activity language")
    maxanswers: Optional[StrictInt] = Field(default=0, description="Maximum answers per page")
    maxattempts: Optional[StrictInt] = Field(default=0, description="Maximum attempts")
    maxpages: Optional[StrictInt] = Field(default=0, description="Number of pages to show")
    mediaclose: Optional[StrictInt] = Field(default=0, description="Display a close button in the popup?")
    mediafile: Optional[StrictStr] = Field(default='', description="Local file path or full external URL")
    mediafiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="mediafiles")
    mediaheight: Optional[StrictInt] = Field(default=0, description="Popup for media file height")
    mediawidth: Optional[StrictInt] = Field(default=0, description="Popup for media with")
    minquestions: Optional[StrictInt] = Field(default=0, description="Minimum number of questions")
    modattempts: Optional[StrictBool] = Field(default=False, description="Allow student review?")
    name: StrictStr = Field(description="Lesson name.")
    nextpagedefault: Optional[StrictInt] = Field(default=0, description="Action for a correct answer")
    ongoing: Optional[StrictBool] = Field(default=False, description="Display ongoing score?")
    password: Optional[StrictStr] = Field(default='', description="Password")
    practice: Optional[StrictBool] = Field(default=False, description="Practice lesson?")
    progressbar: Optional[StrictBool] = Field(default=False, description="Display progress bar?")
    retake: Optional[StrictBool] = Field(default=False, description="Re-takes allowed")
    review: Optional[StrictBool] = Field(default=False, description="Provide option to try a question again")
    slideshow: Optional[StrictBool] = Field(default=False, description="Display lesson as slideshow")
    timelimit: Optional[StrictInt] = Field(default=0, description="Time limit")
    timemodified: Optional[StrictInt] = Field(default=0, description="Last time settings were updated")
    usemaxgrade: Optional[StrictInt] = Field(default=0, description="How to calculate the final grade")
    usepassword: Optional[StrictBool] = Field(default=False, description="Password protected lesson?")
    width: Optional[StrictInt] = Field(default=0, description="Slideshow width")
    __properties: ClassVar[List[str]] = ["activitylink", "allowofflineattempts", "available", "bgcolor", "completionendreached", "completiontimespent", "conditions", "course", "coursemodule", "custom", "deadline", "dependency", "displayleft", "displayleftif", "feedback", "grade", "height", "id", "intro", "introfiles", "introformat", "lang", "maxanswers", "maxattempts", "maxpages", "mediaclose", "mediafile", "mediafiles", "mediaheight", "mediawidth", "minquestions", "modattempts", "name", "nextpagedefault", "ongoing", "password", "practice", "progressbar", "retake", "review", "slideshow", "timelimit", "timemodified", "usemaxgrade", "usepassword", "width"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModLessonGetLessonResponseLesson from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in mediafiles (list)
        _items = []
        if self.mediafiles:
            for _item_mediafiles in self.mediafiles:
                if _item_mediafiles:
                    _items.append(_item_mediafiles.to_dict())
            _dict['mediafiles'] = _items
        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModLessonGetLessonResponseLesson from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModLessonGetLessonResponseLesson" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "activitylink": obj.get("activitylink") if obj.get("activitylink") is not None else 0,
            "allowofflineattempts": obj.get("allowofflineattempts") if obj.get("allowofflineattempts") is not None else False,
            "available": obj.get("available") if obj.get("available") is not None else 0,
            "bgcolor": obj.get("bgcolor") if obj.get("bgcolor") is not None else '',
            "completionendreached": obj.get("completionendreached") if obj.get("completionendreached") is not None else 0,
            "completiontimespent": obj.get("completiontimespent") if obj.get("completiontimespent") is not None else 0,
            "conditions": obj.get("conditions") if obj.get("conditions") is not None else '',
            "course": obj.get("course") if obj.get("course") is not None else 0,
            "coursemodule": obj.get("coursemodule") if obj.get("coursemodule") is not None else 0,
            "custom": obj.get("custom") if obj.get("custom") is not None else False,
            "deadline": obj.get("deadline") if obj.get("deadline") is not None else 0,
            "dependency": obj.get("dependency") if obj.get("dependency") is not None else 0,
            "displayleft": obj.get("displayleft") if obj.get("displayleft") is not None else False,
            "displayleftif": obj.get("displayleftif") if obj.get("displayleftif") is not None else 0,
            "feedback": obj.get("feedback") if obj.get("feedback") is not None else False,
            "grade": obj.get("grade") if obj.get("grade") is not None else 0,
            "height": obj.get("height") if obj.get("height") is not None else 0,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "intro": obj.get("intro") if obj.get("intro") is not None else '',
            "introfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat") if obj.get("introformat") is not None else 0,
            "lang": obj.get("lang"),
            "maxanswers": obj.get("maxanswers") if obj.get("maxanswers") is not None else 0,
            "maxattempts": obj.get("maxattempts") if obj.get("maxattempts") is not None else 0,
            "maxpages": obj.get("maxpages") if obj.get("maxpages") is not None else 0,
            "mediaclose": obj.get("mediaclose") if obj.get("mediaclose") is not None else 0,
            "mediafile": obj.get("mediafile") if obj.get("mediafile") is not None else '',
            "mediafiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["mediafiles"]] if obj.get("mediafiles") is not None else None,
            "mediaheight": obj.get("mediaheight") if obj.get("mediaheight") is not None else 0,
            "mediawidth": obj.get("mediawidth") if obj.get("mediawidth") is not None else 0,
            "minquestions": obj.get("minquestions") if obj.get("minquestions") is not None else 0,
            "modattempts": obj.get("modattempts") if obj.get("modattempts") is not None else False,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "nextpagedefault": obj.get("nextpagedefault") if obj.get("nextpagedefault") is not None else 0,
            "ongoing": obj.get("ongoing") if obj.get("ongoing") is not None else False,
            "password": obj.get("password") if obj.get("password") is not None else '',
            "practice": obj.get("practice") if obj.get("practice") is not None else False,
            "progressbar": obj.get("progressbar") if obj.get("progressbar") is not None else False,
            "retake": obj.get("retake") if obj.get("retake") is not None else False,
            "review": obj.get("review") if obj.get("review") is not None else False,
            "slideshow": obj.get("slideshow") if obj.get("slideshow") is not None else False,
            "timelimit": obj.get("timelimit") if obj.get("timelimit") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "usemaxgrade": obj.get("usemaxgrade") if obj.get("usemaxgrade") is not None else 0,
            "usepassword": obj.get("usepassword") if obj.get("usepassword") is not None else False,
            "width": obj.get("width") if obj.get("width") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
from poodle_async_full.models.mod_data_get_entries_response_entries_inner_contents_inner import ModDataGetEntriesResponseEntriesInnerContentsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModDataGetEntriesResponseEntriesInner(BaseModel):
    """
    ModDataGetEntriesResponseEntriesInner
    """ # noqa: E501
    approved: StrictBool = Field(description="Whether the entry has been approved (if the database is configured in that way).")
    canmanageentry: StrictBool = Field(description="Whether the current user can manage this entry")
    contents: Optional[List[ModDataGetEntriesResponseEntriesInnerContentsInner]] = Field(default=None, description="The record contents.")
    dataid: StrictInt = Field(description="The database id this record belongs to.")
    fullname: Optional[StrictStr] = Field(default='', description="The user who created the entry fullname.")
    groupid: StrictInt = Field(description="The group id this record belongs to (0 for no groups).")
    id: StrictInt = Field(description="Record id.")
    tags: Optional[List[CoreBlogGetEntriesResponseEntriesInnerTagsInner]] = Field(default=None, description="Tags.")
    timecreated: StrictInt = Field(description="Time the record was created.")
    timemodified: StrictInt = Field(description="Last time the record was modified.")
    userid: StrictInt = Field(description="The id of the user who created the record.")
    __properties: ClassVar[List[str]] = ["approved", "canmanageentry", "contents", "dataid", "fullname", "groupid", "id", "tags", "timecreated", "timemodified", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModDataGetEntriesResponseEntriesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in contents (list)
        _items = []
        if self.contents:
            for _item_contents in self.contents:
                if _item_contents:
                    _items.append(_item_contents.to_dict())
            _dict['contents'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModDataGetEntriesResponseEntriesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModDataGetEntriesResponseEntriesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "approved": obj.get("approved") if obj.get("approved") is not None else False,
            "canmanageentry": obj.get("canmanageentry") if obj.get("canmanageentry") is not None else False,
            "contents": [ModDataGetEntriesResponseEntriesInnerContentsInner.from_dict(_item) for _item in obj["contents"]] if obj.get("contents") is not None else None,
            "dataid": obj.get("dataid") if obj.get("dataid") is not None else 0,
            "fullname": obj.get("fullname") if obj.get("fullname") is not None else '',
            "groupid": obj.get("groupid") if obj.get("groupid") is not None else 0,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "tags": [CoreBlogGetEntriesResponseEntriesInnerTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "userid": obj.get("userid") if obj.get("userid") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner(BaseModel):
    """
    ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner
    """ # noqa: E501
    assessmentend: Optional[StrictInt] = Field(default=0, description="0 = will be closed manually, greater than 0 the timestamp of the end of the assessment phase.")
    assessmentstart: Optional[StrictInt] = Field(default=0, description="0 = will be started manually, greater than 0 the timestamp of the start of the assessment phase.")
    conclusion: Optional[StrictStr] = Field(default=None, description="A text to be displayed at the end of the workshop.")
    conclusionfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="conclusionfiles")
    conclusionformat: Optional[StrictInt] = Field(default=0, description="conclusion format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    course: StrictInt = Field(description="Course id this workshop is part of.")
    coursemodule: StrictInt = Field(description="coursemodule")
    evaluation: Optional[StrictStr] = Field(default='', description="The recently used grading evaluation method.")
    examplesmode: Optional[StrictInt] = Field(default=0, description="0 = example assessments are voluntary, 1 = examples must be assessed before submission,                     2 = examples are available after own submission and must be assessed before peer/self assessment phase.")
    grade: Optional[Union[StrictFloat, StrictInt]] = Field(default=80, description="The maximum grade for submission.")
    gradedecimals: Optional[StrictInt] = Field(default=0, description="Number of digits that should be shown after the decimal point when displaying grades.")
    gradinggrade: Optional[Union[StrictFloat, StrictInt]] = Field(default=20, description="The maximum grade for assessment.")
    id: StrictInt = Field(description="The primary key of the record.")
    instructauthors: Optional[StrictStr] = Field(default=None, description="Instructions for the submission phase.")
    instructauthorsfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="instructauthorsfiles")
    instructauthorsformat: Optional[StrictInt] = Field(default=0, description="instructauthors format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    instructreviewers: Optional[StrictStr] = Field(default=None, description="Instructions for the assessment phase.")
    instructreviewersfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="instructreviewersfiles")
    instructreviewersformat: Optional[StrictInt] = Field(default=0, description="instructreviewers format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    intro: Optional[StrictStr] = Field(description="Workshop introduction text.")
    introfiles: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="introfiles")
    introformat: Optional[StrictInt] = Field(default=0, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(description="Forced activity language")
    latesubmissions: Optional[StrictBool] = Field(default=False, description="Allow submitting the work after the deadline.")
    maxbytes: Optional[StrictInt] = Field(default=0, description="Maximum size of the one attached file.")
    name: StrictStr = Field(description="Workshop name.")
    nattachments: Optional[StrictInt] = Field(default=0, description="Maximum number of submission attachments.")
    overallfeedbackfiles: Optional[StrictInt] = Field(default=0, description="Number of allowed attachments to the overall feedback.")
    overallfeedbackfiletypes: Optional[StrictStr] = Field(default=None, description="Comma separated list of file extensions.")
    overallfeedbackmaxbytes: Optional[StrictInt] = Field(default=0, description="Maximum size of one file attached to the overall feedback.")
    overallfeedbackmode: Optional[StrictInt] = Field(default=0, description="Mode of the overall feedback support.")
    phase: Optional[StrictInt] = Field(default=0, description="The current phase of workshop (0 = not available, 1 = submission, 2 = assessment, 3 = closed).")
    phaseswitchassessment: Optional[StrictBool] = Field(default=False, description="Automatically switch to the assessment phase after the submissions deadline.")
    strategy: Optional[StrictStr] = Field(default='', description="The type of the current grading strategy used in this workshop.")
    submissionend: Optional[StrictInt] = Field(default=0, description="0 = will be closed manually, greater than 0 the timestamp of the end of the submission phase.")
    submissionfiletypes: Optional[StrictStr] = Field(default=None, description="Comma separated list of file extensions.")
    submissionstart: Optional[StrictInt] = Field(default=0, description="0 = will be started manually, greater than 0 the timestamp of the start of the submission phase.")
    submissiontypefile: Optional[StrictInt] = Field(default=0, description="Indicates whether a file upload is required as part of each submission. 0 for no, 1 for optional, 2 for required.")
    submissiontypetext: Optional[StrictInt] = Field(default=0, description="Indicates whether text is required as part of each submission. 0 for no, 1 for optional, 2 for required.")
    timemodified: Optional[StrictInt] = Field(default=0, description="The timestamp when the module was modified.")
    useexamples: Optional[StrictBool] = Field(default=False, description="Optional feature: students practise evaluating on example submissions from teacher.")
    usepeerassessment: Optional[StrictBool] = Field(default=False, description="Optional feature: students perform peer assessment of others' work.")
    useselfassessment: Optional[StrictBool] = Field(default=False, description="Optional feature: students perform self assessment of their own work.")
    __properties: ClassVar[List[str]] = ["assessmentend", "assessmentstart", "conclusion", "conclusionfiles", "conclusionformat", "course", "coursemodule", "evaluation", "examplesmode", "grade", "gradedecimals", "gradinggrade", "id", "instructauthors", "instructauthorsfiles", "instructauthorsformat", "instructreviewers", "instructreviewersfiles", "instructreviewersformat", "intro", "introfiles", "introformat", "lang", "latesubmissions", "maxbytes", "name", "nattachments", "overallfeedbackfiles", "overallfeedbackfiletypes", "overallfeedbackmaxbytes", "overallfeedbackmode", "phase", "phaseswitchassessment", "strategy", "submissionend", "submissionfiletypes", "submissionstart", "submissiontypefile", "submissiontypetext", "timemodified", "useexamples", "usepeerassessment", "useselfassessment"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in conclusionfiles (list)
        _items = []
        if self.conclusionfiles:
            for _item_conclusionfiles in self.conclusionfiles:
                if _item_conclusionfiles:
                    _items.append(_item_conclusionfiles.to_dict())
            _dict['conclusionfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in instructauthorsfiles (list)
        _items = []
        if self.instructauthorsfiles:
            for _item_instructauthorsfiles in self.instructauthorsfiles:
                if _item_instructauthorsfiles:
                    _items.append(_item_instructauthorsfiles.to_dict())
            _dict['instructauthorsfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in instructreviewersfiles (list)
        _items = []
        if self.instructreviewersfiles:
            for _item_instructreviewersfiles in self.instructreviewersfiles:
                if _item_instructreviewersfiles:
                    _items.append(_item_instructreviewersfiles.to_dict())
            _dict['instructreviewersfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if conclusion (nullable) is None
        # and model_fields_set contains the field
        if self.conclusion is None and "conclusion" in self.model_fields_set:
            _dict['conclusion'] = None

        # set to None if conclusionformat (nullable) is None
        # and model_fields_set contains the field
        if self.conclusionformat is None and "conclusionformat" in self.model_fields_set:
            _dict['conclusionformat'] = None

        # set to None if instructauthors (nullable) is None
        # and model_fields_set contains the field
        if self.instructauthors is None and "instructauthors" in self.model_fields_set:
            _dict['instructauthors'] = None

        # set to None if instructauthorsformat (nullable) is None
        # and model_fields_set contains the field
        if self.instructauthorsformat is None and "instructauthorsformat" in self.model_fields_set:
            _dict['instructauthorsformat'] = None

        # set to None if instructreviewers (nullable) is None
        # and model_fields_set contains the field
        if self.instructreviewers is None and "instructreviewers" in self.model_fields_set:
            _dict['instructreviewers'] = None

        # set to None if instructreviewersformat (nullable) is None
        # and model_fields_set contains the field
        if self.instructreviewersformat is None and "instructreviewersformat" in self.model_fields_set:
            _dict['instructreviewersformat'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if overallfeedbackfiletypes (nullable) is None
        # and model_fields_set contains the field
        if self.overallfeedbackfiletypes is None and "overallfeedbackfiletypes" in self.model_fields_set:
            _dict['overallfeedbackfiletypes'] = None

        # set to None if submissionfiletypes (nullable) is None
        # and model_fields_set contains the field
        if self.submissionfiletypes is None and "submissionfiletypes" in self.model_fields_set:
            _dict['submissionfiletypes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "assessmentend": obj.get("assessmentend") if obj.get("assessmentend") is not None else 0,
            "assessmentstart": obj.get("assessmentstart") if obj.get("assessmentstart") is not None else 0,
            "conclusion": obj.get("conclusion"),
            "conclusionfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["conclusionfiles"]] if obj.get("conclusionfiles") is not None else None,
            "conclusionformat": obj.get("conclusionformat") if obj.get("conclusionformat") is not None else 0,
            "course": obj.get("course") if obj.get("course") is not None else 0,
            "coursemodule": obj.get("coursemodule") if obj.get("coursemodule") is not None else 0,
            "evaluation": obj.get("evaluation") if obj.get("evaluation") is not None else '',
            "examplesmode": obj.get("examplesmode") if obj.get("examplesmode") is not None else 0,
            "grade": obj.get("grade") if obj.get("grade") is not None else 80,
            "gradedecimals": obj.get("gradedecimals") if obj.get("gradedecimals") is not None else 0,
            "gradinggrade": obj.get("gradinggrade") if obj.get("gradinggrade") is not None else 20,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "instructauthors": obj.get("instructauthors"),
            "instructauthorsfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["instructauthorsfiles"]] if obj.get("instructauthorsfiles") is not None else None,
            "instructauthorsformat": obj.get("instructauthorsformat") if obj.get("instructauthorsformat") is not None else 0,
            "instructreviewers": obj.get("instructreviewers"),
            "instructreviewersfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["instructreviewersfiles"]] if obj.get("instructreviewersfiles") is not None else None,
            "instructreviewersformat": obj.get("instructreviewersformat") if obj.get("instructreviewersformat") is not None else 0,
            "intro": obj.get("intro") if obj.get("intro") is not None else '',
            "introfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat") if obj.get("introformat") is not None else 0,
            "lang": obj.get("lang"),
            "latesubmissions": obj.get("latesubmissions") if obj.get("latesubmissions") is not None else False,
            "maxbytes": obj.get("maxbytes") if obj.get("maxbytes") is not None else 0,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "nattachments": obj.get("nattachments") if obj.get("nattachments") is not None else 0,
            "overallfeedbackfiles": obj.get("overallfeedbackfiles") if obj.get("overallfeedbackfiles") is not None else 0,
            "overallfeedbackfiletypes": obj.get("overallfeedbackfiletypes"),
            "overallfeedbackmaxbytes": obj.get("overallfeedbackmaxbytes") if obj.get("overallfeedbackmaxbytes") is not None else 0,
            "overallfeedbackmode": obj.get("overallfeedbackmode") if obj.get("overallfeedbackmode") is not None else 0,
            "phase": obj.get("phase") if obj.get("phase") is not None else 0,
            "phaseswitchassessment": obj.get("phaseswitchassessment") if obj.get("phaseswitchassessment") is not None else False,
            "strategy": obj.get("strategy") if obj.get("strategy") is not None else '',
            "submissionend": obj.get("submissionend") if obj.get("submissionend") is not None else 0,
            "submissionfiletypes": obj.get("submissionfiletypes"),
            "submissionstart": obj.get("submissionstart") if obj.get("submissionstart") is not None else 0,
            "submissiontypefile": obj.get("submissiontypefile") if obj.get("submissiontypefile") is not None else 0,
            "submissiontypetext": obj.get("submissiontypetext") if obj.get("submissiontypetext") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "useexamples": obj.get("useexamples") if obj.get("useexamples") is not None else False,
            "usepeerassessment": obj.get("usepeerassessment") if obj.get("usepeerassessment") is not None else False,
            "useselfassessment": obj.get("useselfassessment") if obj.get("useselfassessment") is not None else False
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions(BaseModel):
    """
    optional category data
    """ # noqa: E501
    aggregateonlygraded: Optional[StrictBool] = Field(default=None, description="exclude empty grades")
    aggregateoutcomes: Optional[StrictBool] = Field(default=None, description="aggregate outcomes")
    aggregation: Optional[StrictInt] = Field(default=None, description="aggregation method")
    aggregationcoef2: Optional[StrictStr] = Field(default=None, description="weight coefficient")
    decimals: Optional[StrictInt] = Field(default=None, description="the decimal count")
    display: Optional[StrictInt] = Field(default=None, description="the display type")
    droplow: Optional[StrictInt] = Field(default=None, description="drop low grades")
    grademax: Optional[StrictInt] = Field(default=None, description="the grade max")
    grademin: Optional[StrictInt] = Field(default=None, description="the grade min")
    gradepass: Optional[StrictInt] = Field(default=None, description="the grade to pass")
    gradetype: Optional[StrictInt] = Field(default=None, description="the grade type")
    hiddenuntil: Optional[StrictInt] = Field(default=None, description="grades hidden until")
    idnumber: Optional[StrictStr] = Field(default=None, description="the category idnumber")
    iteminfo: Optional[StrictStr] = Field(default=None, description="the category iteminfo")
    itemname: Optional[StrictStr] = Field(default=None, description="the category total name")
    locktime: Optional[StrictInt] = Field(default=None, description="lock grades after")
    parentcategoryid: Optional[StrictInt] = Field(default=None, description="The parent category id")
    parentcategoryidnumber: Optional[StrictStr] = Field(default=None, description="the parent category idnumber")
    weightoverride: Optional[StrictBool] = Field(default=None, description="weight adjusted")
    __properties: ClassVar[List[str]] = ["aggregateonlygraded", "aggregateoutcomes", "aggregation", "aggregationcoef2", "decimals", "display", "droplow", "grademax", "grademin", "gradepass", "gradetype", "hiddenuntil", "idnumber", "iteminfo", "itemname", "locktime", "parentcategoryid", "parentcategoryidnumber", "weightoverride"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if aggregateonlygraded (nullable) is None
        # and model_fields_set contains the field
        if self.aggregateonlygraded is None and "aggregateonlygraded" in self.model_fields_set:
            _dict['aggregateonlygraded'] = None

        # set to None if aggregateoutcomes (nullable) is None
        # and model_fields_set contains the field
        if self.aggregateoutcomes is None and "aggregateoutcomes" in self.model_fields_set:
            _dict['aggregateoutcomes'] = None

        # set to None if aggregation (nullable) is None
        # and model_fields_set contains the field
        if self.aggregation is None and "aggregation" in self.model_fields_set:
            _dict['aggregation'] = None

        # set to None if aggregationcoef2 (nullable) is None
        # and model_fields_set contains the field
        if self.aggregationcoef2 is None and "aggregationcoef2" in self.model_fields_set:
            _dict['aggregationcoef2'] = None

        # set to None if decimals (nullable) is None
        # and model_fields_set contains the field
        if self.decimals is None and "decimals" in self.model_fields_set:
            _dict['decimals'] = None

        # set to None if display (nullable) is None
        # and model_fields_set contains the field
        if self.display is None and "display" in self.model_fields_set:
            _dict['display'] = None

        # set to None if droplow (nullable) is None
        # and model_fields_set contains the field
        if self.droplow is None and "droplow" in self.model_fields_set:
            _dict['droplow'] = None

        # set to None if grademax (nullable) is None
        # and model_fields_set contains the field
        if self.grademax is None and "grademax" in self.model_fields_set:
            _dict['grademax'] = None

        # set to None if grademin (nullable) is None
        # and model_fields_set contains the field
        if self.grademin is None and "grademin" in self.model_fields_set:
            _dict['grademin'] = None

        # set to None if gradepass (nullable) is None
        # and model_fields_set contains the field
        if self.gradepass is None and "gradepass" in self.model_fields_set:
            _dict['gradepass'] = None

        # set to None if gradetype (nullable) is None
        # and model_fields_set contains the field
        if self.gradetype is None and "gradetype" in self.model_fields_set:
            _dict['gradetype'] = None

        # set to None if hiddenuntil (nullable) is None
        # and model_fields_set contains the field
        if self.hiddenuntil is None and "hiddenuntil" in self.model_fields_set:
            _dict['hiddenuntil'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if iteminfo (nullable) is None
        # and model_fields_set contains the field
        if self.iteminfo is None and "iteminfo" in self.model_fields_set:
            _dict['iteminfo'] = None

        # set to None if itemname (nullable) is None
        # and model_fields_set contains the field
        if self.itemname is None and "itemname" in self.model_fields_set:
            _dict['itemname'] = None

        # set to None if locktime (nullable) is None
        # and model_fields_set contains the field
        if self.locktime is None and "locktime" in self.model_fields_set:
            _dict['locktime'] = None

        # set to None if parentcategoryid (nullable) is None
        # and model_fields_set contains the field
        if self.parentcategoryid is None and "parentcategoryid" in self.model_fields_set:
            _dict['parentcategoryid'] = None

        # set to None if parentcategoryidnumber (nullable) is None
        # and model_fields_set contains the field
        if self.parentcategoryidnumber is None and "parentcategoryidnumber" in self.model_fields_set:
            _dict['parentcategoryidnumber'] = None

        # set to None if weightoverride (nullable) is None
        # and model_fields_set contains the field
        if self.weightoverride is None and "weightoverride" in self.model_fields_set:
            _dict['weightoverride'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "aggregateonlygraded": obj.get("aggregateonlygraded"),
            "aggregateoutcomes": obj.get("aggregateoutcomes"),
            "aggregation": obj.get("aggregation"),
            "aggregationcoef2": obj.get("aggregationcoef2"),
            "decimals": obj.get("decimals"),
            "display": obj.get("display"),
            "droplow": obj.get("droplow"),
            "grademax": obj.get("grademax"),
            "grademin": obj.get("grademin"),
            "gradepass": obj.get("gradepass"),
            "gradetype": obj.get("gradetype"),
            "hiddenuntil": obj.get("hiddenuntil"),
            "idnumber": obj.get("idnumber"),
            "iteminfo": obj.get("iteminfo"),
            "itemname": obj.get("itemname"),
            "locktime": obj.get("locktime"),
            "parentcategoryid": obj.get("parentcategoryid"),
            "parentcategoryidnumber": obj.get("parentcategoryidnumber"),
            "weightoverride": obj.get("weightoverride")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner(BaseModel):
    """
    ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner
    """ # noqa: E501
    anonymous: StrictInt = Field(description="Whether the feedback is anonymous.")
    autonumbering: StrictBool = Field(description="Whether questions should be auto-numbered.")
    completionsubmit: StrictBool = Field(description="If this field is set to 1, then the activity will be automatically marked as complete on submission.")
    course: StrictInt = Field(description="Course id this feedback is part of.")
    coursemodule: StrictInt = Field(description="coursemodule")
    email_notification: Optional[StrictBool] = Field(default=False, description="Whether email notifications will be sent to teachers.")
    id: StrictInt = Field(description="The primary key of the record.")
    intro: StrictStr = Field(description="Feedback introduction text.")
    introfiles: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="introfiles")
    introformat: Optional[StrictInt] = Field(default=0, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(description="Forced activity language")
    multiple_submit: StrictBool = Field(description="Whether multiple submissions are allowed.")
    name: StrictStr = Field(description="Feedback name.")
    page_after_submit: Optional[StrictStr] = Field(default='', description="Text to display after submission.")
    page_after_submitformat: Optional[StrictInt] = Field(default=0, description="page_after_submit format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    pageaftersubmitfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="pageaftersubmitfiles")
    publish_stats: StrictBool = Field(description="Whether stats should be published.")
    site_after_submit: Optional[StrictStr] = Field(default='', description="Link to next page after submission.")
    timeclose: Optional[StrictInt] = Field(default=0, description="Allow answers until this time.")
    timemodified: Optional[StrictInt] = Field(default=0, description="The time this record was modified.")
    timeopen: Optional[StrictInt] = Field(default=0, description="Allow answers from this time.")
    __properties: ClassVar[List[str]] = ["anonymous", "autonumbering", "completionsubmit", "course", "coursemodule", "email_notification", "id", "intro", "introfiles", "introformat", "lang", "multiple_submit", "name", "page_after_submit", "page_after_submitformat", "pageaftersubmitfiles", "publish_stats", "site_after_submit", "timeclose", "timemodified", "timeopen"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in pageaftersubmitfiles (list)
        _items = []
        if self.pageaftersubmitfiles:
            for _item_pageaftersubmitfiles in self.pageaftersubmitfiles:
                if _item_pageaftersubmitfiles:
                    _items.append(_item_pageaftersubmitfiles.to_dict())
            _dict['pageaftersubmitfiles'] = _items
        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if page_after_submitformat (nullable) is None
        # and model_fields_set contains the field
        if self.page_after_submitformat is None and "page_after_submitformat" in self.model_fields_set:
            _dict['page_after_submitformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "anonymous": obj.get("anonymous") if obj.get("anonymous") is not None else 0,
            "autonumbering": obj.get("autonumbering") if obj.get("autonumbering") is not None else True,
            "completionsubmit": obj.get("completionsubmit") if obj.get("completionsubmit") is not None else False,
            "course": obj.get("course") if obj.get("course") is not None else 0,
            "coursemodule": obj.get("coursemodule") if obj.get("coursemodule") is not None else 0,
            "email_notification": obj.get("email_notification") if obj.get("email_notification") is not None else False,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "intro": obj.get("intro") if obj.get("intro") is not None else '',
            "introfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat") if obj.get("introformat") is not None else 0,
            "lang": obj.get("lang"),
            "multiple_submit": obj.get("multiple_submit") if obj.get("multiple_submit") is not None else True,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "page_after_submit": obj.get("page_after_submit") if obj.get("page_after_submit") is not None else '',
            "page_after_submitformat": obj.get("page_after_submitformat") if obj.get("page_after_submitformat") is not None else 0,
            "pageaftersubmitfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["pageaftersubmitfiles"]] if obj.get("pageaftersubmitfiles") is not None else None,
            "publish_stats": obj.get("publish_stats") if obj.get("publish_stats") is not None else False,
            "site_after_submit": obj.get("site_after_submit") if obj.get("site_after_submit") is not None else '',
            "timeclose": obj.get("timeclose") if obj.get("timeclose") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "timeopen": obj.get("timeopen") if obj.get("timeopen") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner(BaseModel):
    """
    ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner
    """ # noqa: E501
    attempt: Optional[StrictInt] = Field(description="Attempt number")
    completion: Optional[StrictInt] = Field(default=None, description="Attempt completion")
    duration: Optional[StrictInt] = Field(description="Attempt duration in seconds")
    h5pactivityid: Optional[StrictInt] = Field(description="ID of the H5P activity")
    id: Optional[StrictInt] = Field(description="ID of the context")
    maxscore: Optional[StrictInt] = Field(description="Attempt max score")
    rawscore: Optional[StrictInt] = Field(description="Attempt score value")
    scaled: Optional[Union[StrictFloat, StrictInt]] = Field(description="Attempt scaled")
    success: Optional[StrictInt] = Field(default=None, description="Attempt success")
    timecreated: Optional[StrictInt] = Field(description="Attempt creation")
    timemodified: Optional[StrictInt] = Field(description="Attempt modified")
    userid: Optional[StrictInt] = Field(description="ID of the user")
    __properties: ClassVar[List[str]] = ["attempt", "completion", "duration", "h5pactivityid", "id", "maxscore", "rawscore", "scaled", "success", "timecreated", "timemodified", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if attempt (nullable) is None
        # and model_fields_set contains the field
        if self.attempt is None and "attempt" in self.model_fields_set:
            _dict['attempt'] = None

        # set to None if completion (nullable) is None
        # and model_fields_set contains the field
        if self.completion is None and "completion" in self.model_fields_set:
            _dict['completion'] = None

        # set to None if duration (nullable) is None
        # and model_fields_set contains the field
        if self.duration is None and "duration" in self.model_fields_set:
            _dict['duration'] = None

        # set to None if h5pactivityid (nullable) is None
        # and model_fields_set contains the field
        if self.h5pactivityid is None and "h5pactivityid" in self.model_fields_set:
            _dict['h5pactivityid'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if maxscore (nullable) is None
        # and model_fields_set contains the field
        if self.maxscore is None and "maxscore" in self.model_fields_set:
            _dict['maxscore'] = None

        # set to None if rawscore (nullable) is None
        # and model_fields_set contains the field
        if self.rawscore is None and "rawscore" in self.model_fields_set:
            _dict['rawscore'] = None

        # set to None if scaled (nullable) is None
        # and model_fields_set contains the field
        if self.scaled is None and "scaled" in self.model_fields_set:
            _dict['scaled'] = None

        # set to None if success (nullable) is None
        # and model_fields_set contains the field
        if self.success is None and "success" in self.model_fields_set:
            _dict['success'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "attempt": obj.get("attempt"),
            "completion": obj.get("completion"),
            "duration": obj.get("duration"),
            "h5pactivityid": obj.get("h5pactivityid"),
            "id": obj.get("id"),
            "maxscore": obj.get("maxscore"),
            "rawscore": obj.get("rawscore"),
            "scaled": obj.get("scaled"),
            "success": obj.get("success"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCompetencyCreatePlanResponseCommentarea(BaseModel):
    """
    CoreCompetencyCreatePlanResponseCommentarea
    """ # noqa: E501
    autostart: StrictBool = Field(description="autostart")
    canpost: StrictBool = Field(description="canpost")
    canpostorhascomments: StrictBool = Field(description="canpostorhascomments")
    canview: StrictBool = Field(description="canview")
    cid: StrictStr = Field(description="cid")
    collapsediconkey: StrictStr = Field(description="collapsediconkey")
    commentarea: StrictStr = Field(description="commentarea")
    component: StrictStr = Field(description="component")
    contextid: StrictInt = Field(description="contextid")
    count: StrictInt = Field(description="count")
    courseid: StrictInt = Field(description="courseid")
    displaycancel: StrictBool = Field(description="displaycancel")
    displaytotalcount: StrictBool = Field(description="displaytotalcount")
    fullwidth: StrictBool = Field(description="fullwidth")
    itemid: StrictInt = Field(description="itemid")
    linktext: StrictStr = Field(description="linktext")
    notoggle: StrictBool = Field(description="notoggle")
    template: StrictStr = Field(description="template")
    __properties: ClassVar[List[str]] = ["autostart", "canpost", "canpostorhascomments", "canview", "cid", "collapsediconkey", "commentarea", "component", "contextid", "count", "courseid", "displaycancel", "displaytotalcount", "fullwidth", "itemid", "linktext", "notoggle", "template"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCompetencyCreatePlanResponseCommentarea from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCompetencyCreatePlanResponseCommentarea from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCompetencyCreatePlanResponseCommentarea" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "autostart": obj.get("autostart") if obj.get("autostart") is not None else False,
            "canpost": obj.get("canpost") if obj.get("canpost") is not None else False,
            "canpostorhascomments": obj.get("canpostorhascomments") if obj.get("canpostorhascomments") is not None else False,
            "canview": obj.get("canview") if obj.get("canview") is not None else False,
            "cid": obj.get("cid") if obj.get("cid") is not None else '',
            "collapsediconkey": obj.get("collapsediconkey") if obj.get("collapsediconkey") is not None else '',
            "commentarea": obj.get("commentarea") if obj.get("commentarea") is not None else '',
            "component": obj.get("component") if obj.get("component") is not None else '',
            "contextid": obj.get("contextid") if obj.get("contextid") is not None else 0,
            "count": obj.get("count") if obj.get("count") is not None else 0,
            "courseid": obj.get("courseid") if obj.get("courseid") is not None else 0,
            "displaycancel": obj.get("displaycancel") if obj.get("displaycancel") is not None else False,
            "displaytotalcount": obj.get("displaytotalcount") if obj.get("displaytotalcount") is not None else False,
            "fullwidth": obj.get("fullwidth") if obj.get("fullwidth") is not None else False,
            "itemid": obj.get("itemid") if obj.get("itemid") is not None else 0,
            "linktext": obj.get("linktext") if obj.get("linktext") is not None else '',
            "notoggle": obj.get("notoggle") if obj.get("notoggle") is not None else False,
            "template": obj.get("template") if obj.get("template") is not None else ''
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner_deployedfile import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner(BaseModel):
    """
    ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner
    """ # noqa: E501
    contenthash: Optional[StrictStr] = Field(default='', description="Sha1 hash of file content.")
    context: StrictInt = Field(description="context")
    course: StrictInt = Field(description="Course id this h5p activity is part of.")
    coursemodule: StrictInt = Field(description="coursemodule")
    deployedfile: Optional[ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile] = None
    displayoptions: StrictInt = Field(description="H5P Button display options.")
    enabletracking: StrictInt = Field(description="Enable xAPI tracking.")
    grade: Optional[StrictInt] = Field(default=0, description="The maximum grade for submission.")
    grademethod: StrictInt = Field(description="Which H5P attempt is used for grading.")
    id: StrictInt = Field(description="The primary key of the record.")
    intro: Optional[StrictStr] = Field(description="H5P activity description.")
    introfiles: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="introfiles")
    introformat: Optional[StrictInt] = Field(default=0, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    name: StrictStr = Field(description="The name of the activity module instance.")
    package: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="package")
    timecreated: Optional[StrictInt] = Field(default=0, description="Timestamp of when the instance was added to the course.")
    timemodified: Optional[StrictInt] = Field(default=0, description="Timestamp of when the instance was last modified.")
    __properties: ClassVar[List[str]] = ["contenthash", "context", "course", "coursemodule", "deployedfile", "displayoptions", "enabletracking", "grade", "grademethod", "id", "intro", "introfiles", "introformat", "name", "package", "timecreated", "timemodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of deployedfile
        if self.deployedfile:
            _dict['deployedfile'] = self.deployedfile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in package (list)
        _items = []
        if self.package:
            for _item_package in self.package:
                if _item_package:
                    _items.append(_item_package.to_dict())
            _dict['package'] = _items
        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "contenthash": obj.get("contenthash") if obj.get("contenthash") is not None else '',
            "context": obj.get("context") if obj.get("context") is not None else 0,
            "course": obj.get("course") if obj.get("course") is not None else 0,
            "coursemodule": obj.get("coursemodule") if obj.get("coursemodule") is not None else 0,
            "deployedfile": ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile.from_dict(obj["deployedfile"]) if obj.get("deployedfile") is not None else None,
            "displayoptions": obj.get("displayoptions") if obj.get("displayoptions") is not None else 0,
            "enabletracking": obj.get("enabletracking") if obj.get("enabletracking") is not None else 0,
            "grade": obj.get("grade") if obj.get("grade") is not None else 0,
            "grademethod": obj.get("grademethod") if obj.get("grademethod") is not None else 0,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "intro": obj.get("intro") if obj.get("intro") is not None else '',
            "introfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat") if obj.get("introformat") is not None else 0,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "package": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["package"]] if obj.get("package") is not None else None,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner_acceptance import ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ToolPolicyGetUserAcceptancesResponsePoliciesInner(BaseModel):
    """
    ToolPolicyGetUserAcceptancesResponsePoliciesInner
    """ # noqa: E501
    acceptance: Optional[ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance] = None
    agreementstyle: Optional[StrictInt] = Field(description="The policy agreement style. 0: consent page, 1: own page.")
    canaccept: Optional[StrictBool] = Field(description="Whether the policy can be accepted.")
    candecline: Optional[StrictBool] = Field(description="Whether the policy can be declined.")
    canrevoke: Optional[StrictBool] = Field(description="Whether the policy can be revoked.")
    content: Optional[StrictStr] = Field(default=None, description="The policy content.")
    contentformat: Optional[StrictInt] = Field(description="content format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    name: Optional[StrictStr] = Field(description="The policy name")
    optional: Optional[StrictInt] = Field(description="Whether the policy is optional. 0: compulsory, 1: optional")
    policyid: Optional[StrictInt] = Field(description="The policy id.")
    revision: Optional[StrictStr] = Field(description="The policy revision.")
    status: Optional[StrictInt] = Field(description="The policy status. 0: draft, 1: active, 2: archived.")
    summary: Optional[StrictStr] = Field(default=None, description="The policy summary.")
    summaryformat: Optional[StrictInt] = Field(description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    versionid: Optional[StrictInt] = Field(description="The policy version id.")
    __properties: ClassVar[List[str]] = ["acceptance", "agreementstyle", "canaccept", "candecline", "canrevoke", "content", "contentformat", "name", "optional", "policyid", "revision", "status", "summary", "summaryformat", "versionid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolPolicyGetUserAcceptancesResponsePoliciesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of acceptance
        if self.acceptance:
            _dict['acceptance'] = self.acceptance.to_dict()
        # set to None if agreementstyle (nullable) is None
        # and model_fields_set contains the field
        if self.agreementstyle is None and "agreementstyle" in self.model_fields_set:
            _dict['agreementstyle'] = None

        # set to None if canaccept (nullable) is None
        # and model_fields_set contains the field
        if self.canaccept is None and "canaccept" in self.model_fields_set:
            _dict['canaccept'] = None

        # set to None if candecline (nullable) is None
        # and model_fields_set contains the field
        if self.candecline is None and "candecline" in self.model_fields_set:
            _dict['candecline'] = None

        # set to None if canrevoke (nullable) is None
        # and model_fields_set contains the field
        if self.canrevoke is None and "canrevoke" in self.model_fields_set:
            _dict['canrevoke'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if contentformat (nullable) is None
        # and model_fields_set contains the field
        if self.contentformat is None and "contentformat" in self.model_fields_set:
            _dict['contentformat'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if optional (nullable) is None
        # and model_fields_set contains the field
        if self.optional is None and "optional" in self.model_fields_set:
            _dict['optional'] = None

        # set to None if policyid (nullable) is None
        # and model_fields_set contains the field
        if self.policyid is None and "policyid" in self.model_fields_set:
            _dict['policyid'] = None

        # set to None if revision (nullable) is None
        # and model_fields_set contains the field
        if self.revision is None and "revision" in self.model_fields_set:
            _dict['revision'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        # set to None if versionid (nullable) is None
        # and model_fields_set contains the field
        if self.versionid is None and "versionid" in self.model_fields_set:
            _dict['versionid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolPolicyGetUserAcceptancesResponsePoliciesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ToolPolicyGetUserAcceptancesResponsePoliciesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "acceptance": ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance.from_dict(obj["acceptance"]) if obj.get("acceptance") is not None else None,
            "agreementstyle": obj.get("agreementstyle"),
            "canaccept": obj.get("canaccept"),
            "candecline": obj.get("candecline"),
            "canrevoke": obj.get("canrevoke"),
            "content": obj.get("content"),
            "contentformat": obj.get("contentformat"),
            "name": obj.get("name"),
            "optional": obj.get("optional"),
            "policyid": obj.get("policyid"),
            "revision": obj.get("revision"),
            "status": obj.get("status"),
            "summary": obj.get("summary"),
            "summaryformat": obj.get("summaryformat"),
            "versionid": obj.get("versionid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreGradesUpdateGradesParametersItemdetails(BaseModel):
    """
    Any grade item settings to alter
    """ # noqa: E501
    deleted: Optional[StrictBool] = Field(default=None, description="True if the grade item should be deleted")
    grademax: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Maximum grade allowed")
    grademin: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Minimum grade allowed")
    gradetype: Optional[StrictInt] = Field(default=None, description="The type of grade (0 = none, 1 = value, 2 = scale, 3 = text)")
    hidden: Optional[StrictBool] = Field(default=None, description="True if the grade item is hidden")
    idnumber: Optional[StrictInt] = Field(default=None, description="Arbitrary ID provided by the module responsible for the grade item")
    itemname: Optional[StrictStr] = Field(default=None, description="The grade item name")
    multfactor: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Multiply all grades by this number")
    plusfactor: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Add this to all grades")
    scaleid: Optional[StrictInt] = Field(default=None, description="The ID of the custom scale being is used")
    __properties: ClassVar[List[str]] = ["deleted", "grademax", "grademin", "gradetype", "hidden", "idnumber", "itemname", "multfactor", "plusfactor", "scaleid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreGradesUpdateGradesParametersItemdetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if deleted (nullable) is None
        # and model_fields_set contains the field
        if self.deleted is None and "deleted" in self.model_fields_set:
            _dict['deleted'] = None

        # set to None if grademax (nullable) is None
        # and model_fields_set contains the field
        if self.grademax is None and "grademax" in self.model_fields_set:
            _dict['grademax'] = None

        # set to None if grademin (nullable) is None
        # and model_fields_set contains the field
        if self.grademin is None and "grademin" in self.model_fields_set:
            _dict['grademin'] = None

        # set to None if gradetype (nullable) is None
        # and model_fields_set contains the field
        if self.gradetype is None and "gradetype" in self.model_fields_set:
            _dict['gradetype'] = None

        # set to None if hidden (nullable) is None
        # and model_fields_set contains the field
        if self.hidden is None and "hidden" in self.model_fields_set:
            _dict['hidden'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if itemname (nullable) is None
        # and model_fields_set contains the field
        if self.itemname is None and "itemname" in self.model_fields_set:
            _dict['itemname'] = None

        # set to None if multfactor (nullable) is None
        # and model_fields_set contains the field
        if self.multfactor is None and "multfactor" in self.model_fields_set:
            _dict['multfactor'] = None

        # set to None if plusfactor (nullable) is None
        # and model_fields_set contains the field
        if self.plusfactor is None and "plusfactor" in self.model_fields_set:
            _dict['plusfactor'] = None

        # set to None if scaleid (nullable) is None
        # and model_fields_set contains the field
        if self.scaleid is None and "scaleid" in self.model_fields_set:
            _dict['scaleid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreGradesUpdateGradesParametersItemdetails from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreGradesUpdateGradesParametersItemdetails" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "deleted": obj.get("deleted"),
            "grademax": obj.get("grademax"),
            "grademin": obj.get("grademin"),
            "gradetype": obj.get("gradetype"),
            "hidden": obj.get("hidden"),
            "idnumber": obj.get("idnumber"),
            "itemname": obj.get("itemname"),
            "multfactor": obj.get("multfactor"),
            "plusfactor": obj.get("plusfactor"),
            "scaleid": obj.get("scaleid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModGlossaryGetGlossariesByCoursesResponseGlossariesInner(BaseModel):
    """
    Glossaries
    """ # noqa: E501
    allowcomments: Optional[StrictInt] = Field(description="If enabled, all participants with permission to create comments will be able to add comments to glossary entries")
    allowduplicatedentries: Optional[StrictInt] = Field(description="If enabled, multiple entries can have the same concept name")
    allowprintview: Optional[StrictInt] = Field(description="If enabled, students are provided with a link to a printer-friendly version of the glossary. The link is always available to teachers")
    approvaldisplayformat: Optional[StrictStr] = Field(description="When approving glossary items you may wish to use a different display format")
    assessed: Optional[StrictInt] = Field(description="Aggregate type")
    assesstimefinish: Optional[StrictInt] = Field(description="Restrict rating to items created before this")
    assesstimestart: Optional[StrictInt] = Field(description="Restrict rating to items created after this")
    browsemodes: List[Optional[StrictStr]]
    canaddentry: Optional[StrictInt] = Field(default=None, description="Whether the user can add a new entry")
    completionentries: Optional[StrictInt] = Field(description="Number of entries to complete")
    course: Optional[StrictInt] = Field(description="Course id")
    coursemodule: Optional[StrictInt] = Field(description="Course module id")
    defaultapproval: Optional[StrictInt] = Field(description="If set to no, entries require approving by a teacher before they are viewable by everyone.")
    displayformat: Optional[StrictStr] = Field(description="Display format type")
    editalways: Optional[StrictInt] = Field(description="Always allow editing")
    entbypage: Optional[StrictInt] = Field(description="Entries shown per page")
    globalglossary: Optional[StrictInt]
    groupingid: Optional[StrictInt] = Field(default=None, description="Group id")
    groupmode: Optional[StrictInt] = Field(default=None, description="Group mode")
    id: Optional[StrictInt] = Field(description="Activity instance id")
    intro: Optional[StrictStr] = Field(description="Activity introduction")
    introfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files in the introduction")
    introformat: Optional[StrictInt] = Field(description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(default=None, description="Forced activity language")
    mainglossary: Optional[StrictInt] = Field(description="If enabled this glossary is a main glossary.")
    name: Optional[StrictStr] = Field(description="Activity name")
    rssarticles: Optional[StrictInt] = Field(description="This setting specifies the number of glossary entry concepts to include in the RSS feed. Between 5 and 20 generally acceptable")
    rsstype: Optional[StrictInt] = Field(description="To enable the RSS feed for this activity, select either concepts with author or concepts without author to be included in the feed")
    scale: Optional[StrictInt] = Field(description="Scale ID")
    section: Optional[StrictInt] = Field(default=None, description="Course section id")
    showall: Optional[StrictInt] = Field(description="If enabled, participants can browse all entries at once")
    showalphabet: Optional[StrictInt] = Field(description="If enabled, participants can browse the glossary by letters of the alphabet")
    showspecial: Optional[StrictInt] = Field(description="If enabled, participants can browse the glossary by special characters, such as @ and #")
    timecreated: Optional[StrictInt] = Field(description="Time created")
    timemodified: Optional[StrictInt] = Field(description="Time modified")
    usedynalink: Optional[StrictInt] = Field(description="If site-wide glossary auto-linking has been enabled by an administrator and this checkbox is ticked, the entry will be automatically linked wherever the concept words and phrases appear throughout the rest of the course.")
    visible: Optional[StrictBool] = Field(default=None, description="Visible")
    __properties: ClassVar[List[str]] = ["allowcomments", "allowduplicatedentries", "allowprintview", "approvaldisplayformat", "assessed", "assesstimefinish", "assesstimestart", "browsemodes", "canaddentry", "completionentries", "course", "coursemodule", "defaultapproval", "displayformat", "editalways", "entbypage", "globalglossary", "groupingid", "groupmode", "id", "intro", "introfiles", "introformat", "lang", "mainglossary", "name", "rssarticles", "rsstype", "scale", "section", "showall", "showalphabet", "showspecial", "timecreated", "timemodified", "usedynalink", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModGlossaryGetGlossariesByCoursesResponseGlossariesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if allowcomments (nullable) is None
        # and model_fields_set contains the field
        if self.allowcomments is None and "allowcomments" in self.model_fields_set:
            _dict['allowcomments'] = None

        # set to None if allowduplicatedentries (nullable) is None
        # and model_fields_set contains the field
        if self.allowduplicatedentries is None and "allowduplicatedentries" in self.model_fields_set:
            _dict['allowduplicatedentries'] = None

        # set to None if allowprintview (nullable) is None
        # and model_fields_set contains the field
        if self.allowprintview is None and "allowprintview" in self.model_fields_set:
            _dict['allowprintview'] = None

        # set to None if approvaldisplayformat (nullable) is None
        # and model_fields_set contains the field
        if self.approvaldisplayformat is None and "approvaldisplayformat" in self.model_fields_set:
            _dict['approvaldisplayformat'] = None

        # set to None if assessed (nullable) is None
        # and model_fields_set contains the field
        if self.assessed is None and "assessed" in self.model_fields_set:
            _dict['assessed'] = None

        # set to None if assesstimefinish (nullable) is None
        # and model_fields_set contains the field
        if self.assesstimefinish is None and "assesstimefinish" in self.model_fields_set:
            _dict['assesstimefinish'] = None

        # set to None if assesstimestart (nullable) is None
        # and model_fields_set contains the field
        if self.assesstimestart is None and "assesstimestart" in self.model_fields_set:
            _dict['assesstimestart'] = None

        # set to None if canaddentry (nullable) is None
        # and model_fields_set contains the field
        if self.canaddentry is None and "canaddentry" in self.model_fields_set:
            _dict['canaddentry'] = None

        # set to None if completionentries (nullable) is None
        # and model_fields_set contains the field
        if self.completionentries is None and "completionentries" in self.model_fields_set:
            _dict['completionentries'] = None

        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if coursemodule (nullable) is None
        # and model_fields_set contains the field
        if self.coursemodule is None and "coursemodule" in self.model_fields_set:
            _dict['coursemodule'] = None

        # set to None if defaultapproval (nullable) is None
        # and model_fields_set contains the field
        if self.defaultapproval is None and "defaultapproval" in self.model_fields_set:
            _dict['defaultapproval'] = None

        # set to None if displayformat (nullable) is None
        # and model_fields_set contains the field
        if self.displayformat is None and "displayformat" in self.model_fields_set:
            _dict['displayformat'] = None

        # set to None if editalways (nullable) is None
        # and model_fields_set contains the field
        if self.editalways is None and "editalways" in self.model_fields_set:
            _dict['editalways'] = None

        # set to None if entbypage (nullable) is None
        # and model_fields_set contains the field
        if self.entbypage is None and "entbypage" in self.model_fields_set:
            _dict['entbypage'] = None

        # set to None if globalglossary (nullable) is None
        # and model_fields_set contains the field
        if self.globalglossary is None and "globalglossary" in self.model_fields_set:
            _dict['globalglossary'] = None

        # set to None if groupingid (nullable) is None
        # and model_fields_set contains the field
        if self.groupingid is None and "groupingid" in self.model_fields_set:
            _dict['groupingid'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if mainglossary (nullable) is None
        # and model_fields_set contains the field
        if self.mainglossary is None and "mainglossary" in self.model_fields_set:
            _dict['mainglossary'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if rssarticles (nullable) is None
        # and model_fields_set contains the field
        if self.rssarticles is None and "rssarticles" in self.model_fields_set:
            _dict['rssarticles'] = None

        # set to None if rsstype (nullable) is None
        # and model_fields_set contains the field
        if self.rsstype is None and "rsstype" in self.model_fields_set:
            _dict['rsstype'] = None

        # set to None if scale (nullable) is None
        # and model_fields_set contains the field
        if self.scale is None and "scale" in self.model_fields_set:
            _dict['scale'] = None

        # set to None if section (nullable) is None
        # and model_fields_set contains the field
        if self.section is None and "section" in self.model_fields_set:
            _dict['section'] = None

        # set to None if showall (nullable) is None
        # and model_fields_set contains the field
        if self.showall is None and "showall" in self.model_fields_set:
            _dict['showall'] = None

        # set to None if showalphabet (nullable) is None
        # and model_fields_set contains the field
        if self.showalphabet is None and "showalphabet" in self.model_fields_set:
            _dict['showalphabet'] = None

        # set to None if showspecial (nullable) is None
        # and model_fields_set contains the field
        if self.showspecial is None and "showspecial" in self.model_fields_set:
            _dict['showspecial'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if usedynalink (nullable) is None
        # and model_fields_set contains the field
        if self.usedynalink is None and "usedynalink" in self.model_fields_set:
            _dict['usedynalink'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModGlossaryGetGlossariesByCoursesResponseGlossariesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModGlossaryGetGlossariesByCoursesResponseGlossariesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "allowcomments": obj.get("allowcomments"),
            "allowduplicatedentries": obj.get("allowduplicatedentries"),
            "allowprintview": obj.get("allowprintview"),
            "approvaldisplayformat": obj.get("approvaldisplayformat"),
            "assessed": obj.get("assessed"),
            "assesstimefinish": obj.get("assesstimefinish"),
            "assesstimestart": obj.get("assesstimestart"),
            "browsemodes": obj.get("browsemodes"),
            "canaddentry": obj.get("canaddentry"),
            "completionentries": obj.get("completionentries"),
            "course": obj.get("course"),
            "coursemodule": obj.get("coursemodule"),
            "defaultapproval": obj.get("defaultapproval"),
            "displayformat": obj.get("displayformat"),
            "editalways": obj.get("editalways"),
            "entbypage": obj.get("entbypage"),
            "globalglossary": obj.get("globalglossary"),
            "groupingid": obj.get("groupingid"),
            "groupmode": obj.get("groupmode"),
            "id": obj.get("id"),
            "intro": obj.get("intro"),
            "introfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat"),
            "lang": obj.get("lang"),
            "mainglossary": obj.get("mainglossary"),
            "name": obj.get("name"),
            "rssarticles": obj.get("rssarticles"),
            "rsstype": obj.get("rsstype"),
            "scale": obj.get("scale"),
            "section": obj.get("section"),
            "showall": obj.get("showall"),
            "showalphabet": obj.get("showalphabet"),
            "showspecial": obj.get("showspecial"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "usedynalink": obj.get("usedynalink"),
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_features_inner import ModBigbluebuttonbnMeetingInfoResponseFeaturesInner
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_presentations_inner import ModBigbluebuttonbnMeetingInfoResponsePresentationsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModBigbluebuttonbnMeetingInfoResponse(BaseModel):
    """
    ModBigbluebuttonbnMeetingInfoResponse
    """ # noqa: E501
    bigbluebuttonbnid: Optional[StrictStr] = Field(description="bigbluebuttonbn instance id")
    canjoin: Optional[StrictBool] = Field(description="Can join")
    closingtime: Optional[StrictInt] = Field(default=None, description="Closing time")
    cmid: Optional[StrictInt] = Field(description="CM id")
    features: Optional[List[ModBigbluebuttonbnMeetingInfoResponseFeaturesInner]] = Field(default=None, description="List of features for the instance")
    groupid: Optional[StrictInt] = Field(default=0, description="bigbluebuttonbn group id")
    guestaccessenabled: Optional[StrictBool] = Field(default=None, description="Guest access enabled")
    guestjoinurl: Optional[StrictStr] = Field(default=None, description="Guest URL")
    guestpassword: Optional[StrictStr] = Field(default=None, description="Guest join password")
    ismoderator: Optional[StrictBool] = Field(description="Is moderator")
    joinurl: Optional[StrictStr] = Field(description="Join URL")
    meetingid: Optional[StrictStr] = Field(description="Meeting id")
    moderatorcount: Optional[StrictInt] = Field(default=None, description="Moderator count")
    moderatorplural: Optional[StrictBool] = Field(default=None, description="Several moderators ?")
    openingtime: Optional[StrictInt] = Field(default=None, description="Opening time")
    participantcount: Optional[StrictInt] = Field(default=None, description="Participant count")
    participantplural: Optional[StrictBool] = Field(default=None, description="Several participants ?")
    presentations: List[ModBigbluebuttonbnMeetingInfoResponsePresentationsInner]
    showpresentations: Optional[StrictBool] = Field(default=None, description="Show presentation file")
    startedat: Optional[StrictInt] = Field(default=None, description="Started at")
    statusclosed: Optional[StrictBool] = Field(default=None, description="Status closed")
    statusmessage: Optional[StrictStr] = Field(default=None, description="Status message")
    statusopen: Optional[StrictBool] = Field(default=None, description="Status open")
    statusrunning: Optional[StrictBool] = Field(default=None, description="Status running")
    userlimit: Optional[StrictInt] = Field(description="User limit")
    __properties: ClassVar[List[str]] = ["bigbluebuttonbnid", "canjoin", "closingtime", "cmid", "features", "groupid", "guestaccessenabled", "guestjoinurl", "guestpassword", "ismoderator", "joinurl", "meetingid", "moderatorcount", "moderatorplural", "openingtime", "participantcount", "participantplural", "presentations", "showpresentations", "startedat", "statusclosed", "statusmessage", "statusopen", "statusrunning", "userlimit"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModBigbluebuttonbnMeetingInfoResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in features (list)
        _items = []
        if self.features:
            for _item_features in self.features:
                if _item_features:
                    _items.append(_item_features.to_dict())
            _dict['features'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in presentations (list)
        _items = []
        if self.presentations:
            for _item_presentations in self.presentations:
                if _item_presentations:
                    _items.append(_item_presentations.to_dict())
            _dict['presentations'] = _items
        # set to None if bigbluebuttonbnid (nullable) is None
        # and model_fields_set contains the field
        if self.bigbluebuttonbnid is None and "bigbluebuttonbnid" in self.model_fields_set:
            _dict['bigbluebuttonbnid'] = None

        # set to None if canjoin (nullable) is None
        # and model_fields_set contains the field
        if self.canjoin is None and "canjoin" in self.model_fields_set:
            _dict['canjoin'] = None

        # set to None if closingtime (nullable) is None
        # and model_fields_set contains the field
        if self.closingtime is None and "closingtime" in self.model_fields_set:
            _dict['closingtime'] = None

        # set to None if cmid (nullable) is None
        # and model_fields_set contains the field
        if self.cmid is None and "cmid" in self.model_fields_set:
            _dict['cmid'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if guestaccessenabled (nullable) is None
        # and model_fields_set contains the field
        if self.guestaccessenabled is None and "guestaccessenabled" in self.model_fields_set:
            _dict['guestaccessenabled'] = None

        # set to None if guestjoinurl (nullable) is None
        # and model_fields_set contains the field
        if self.guestjoinurl is None and "guestjoinurl" in self.model_fields_set:
            _dict['guestjoinurl'] = None

        # set to None if guestpassword (nullable) is None
        # and model_fields_set contains the field
        if self.guestpassword is None and "guestpassword" in self.model_fields_set:
            _dict['guestpassword'] = None

        # set to None if ismoderator (nullable) is None
        # and model_fields_set contains the field
        if self.ismoderator is None and "ismoderator" in self.model_fields_set:
            _dict['ismoderator'] = None

        # set to None if joinurl (nullable) is None
        # and model_fields_set contains the field
        if self.joinurl is None and "joinurl" in self.model_fields_set:
            _dict['joinurl'] = None

        # set to None if meetingid (nullable) is None
        # and model_fields_set contains the field
        if self.meetingid is None and "meetingid" in self.model_fields_set:
            _dict['meetingid'] = None

        # set to None if moderatorcount (nullable) is None
        # and model_fields_set contains the field
        if self.moderatorcount is None and "moderatorcount" in self.model_fields_set:
            _dict['moderatorcount'] = None

        # set to None if moderatorplural (nullable) is None
        # and model_fields_set contains the field
        if self.moderatorplural is None and "moderatorplural" in self.model_fields_set:
            _dict['moderatorplural'] = None

        # set to None if openingtime (nullable) is None
        # and model_fields_set contains the field
        if self.openingtime is None and "openingtime" in self.model_fields_set:
            _dict['openingtime'] = None

        # set to None if participantcount (nullable) is None
        # and model_fields_set contains the field
        if self.participantcount is None and "participantcount" in self.model_fields_set:
            _dict['participantcount'] = None

        # set to None if participantplural (nullable) is None
        # and model_fields_set contains the field
        if self.participantplural is None and "participantplural" in self.model_fields_set:
            _dict['participantplural'] = None

        # set to None if showpresentations (nullable) is None
        # and model_fields_set contains the field
        if self.showpresentations is None and "showpresentations" in self.model_fields_set:
            _dict['showpresentations'] = None

        # set to None if startedat (nullable) is None
        # and model_fields_set contains the field
        if self.startedat is None and "startedat" in self.model_fields_set:
            _dict['startedat'] = None

        # set to None if statusclosed (nullable) is None
        # and model_fields_set contains the field
        if self.statusclosed is None and "statusclosed" in self.model_fields_set:
            _dict['statusclosed'] = None

        # set to None if statusmessage (nullable) is None
        # and model_fields_set contains the field
        if self.statusmessage is None and "statusmessage" in self.model_fields_set:
            _dict['statusmessage'] = None

        # set to None if statusopen (nullable) is None
        # and model_fields_set contains the field
        if self.statusopen is None and "statusopen" in self.model_fields_set:
            _dict['statusopen'] = None

        # set to None if statusrunning (nullable) is None
        # and model_fields_set contains the field
        if self.statusrunning is None and "statusrunning" in self.model_fields_set:
            _dict['statusrunning'] = None

        # set to None if userlimit (nullable) is None
        # and model_fields_set contains the field
        if self.userlimit is None and "userlimit" in self.model_fields_set:
            _dict['userlimit'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModBigbluebuttonbnMeetingInfoResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModBigbluebuttonbnMeetingInfoResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "bigbluebuttonbnid": obj.get("bigbluebuttonbnid"),
            "canjoin": obj.get("canjoin"),
            "closingtime": obj.get("closingtime"),
            "cmid": obj.get("cmid"),
            "features": [ModBigbluebuttonbnMeetingInfoResponseFeaturesInner.from_dict(_item) for _item in obj["features"]] if obj.get("features") is not None else None,
            "groupid": obj.get("groupid") if obj.get("groupid") is not None else 0,
            "guestaccessenabled": obj.get("guestaccessenabled"),
            "guestjoinurl": obj.get("guestjoinurl"),
            "guestpassword": obj.get("guestpassword"),
            "ismoderator": obj.get("ismoderator"),
            "joinurl": obj.get("joinurl"),
            "meetingid": obj.get("meetingid"),
            "moderatorcount": obj.get("moderatorcount"),
            "moderatorplural": obj.get("moderatorplural"),
            "openingtime": obj.get("openingtime"),
            "participantcount": obj.get("participantcount"),
            "participantplural": obj.get("participantplural"),
            "presentations": [ModBigbluebuttonbnMeetingInfoResponsePresentationsInner.from_dict(_item) for _item in obj["presentations"]] if obj.get("presentations") is not None else None,
            "showpresentations": obj.get("showpresentations"),
            "startedat": obj.get("startedat"),
            "statusclosed": obj.get("statusclosed"),
            "statusmessage": obj.get("statusmessage"),
            "statusopen": obj.get("statusopen"),
            "statusrunning": obj.get("statusrunning"),
            "userlimit": obj.get("userlimit")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


